@@ -2,14 +2,15 @@
 mod kube_api;
 pub(crate) mod stream;
 
-use super::app::{self, App};
+use core::convert::TryFrom;
+use std::sync::Arc;
 
 use anyhow::{anyhow, Result};
-use core::convert::TryFrom;
 use kube::Client;
-use std::sync::Arc;
 use tokio::sync::Mutex;
 
+use crate::app::App;
+
 #[derive(Debug, PartialEq)]
 pub enum IoEvent {
   GetKubeConfig,
@@ -21,6 +22,10 @@ pub enum IoEvent {
   GetStatefulSets,
   GetReplicaSets,
   GetDeployments,
+  GetJobs,
+  GetDaemonSets,
+  GetCronJobs,
+  GetSecrets,
   GetMetrics,
   RefreshClient,
 }
@@ -127,6 +132,18 @@ impl<'a> Network<'a> {
       IoEvent::GetReplicaSets => {
         self.get_replica_sets().await;
       }
+      IoEvent::GetJobs => {
+        self.get_jobs().await;
+      }
+      IoEvent::GetDaemonSets => {
+        self.get_daemon_sets_jobs().await;
+      }
+      IoEvent::GetCronJobs => {
+        self.get_cron_jobs().await;
+      }
+      IoEvent::GetSecrets => {
+        self.get_secrets().await;
+      }
       IoEvent::GetDeployments => {
         self.get_deployments().await;
       }
