@@ -1,9 +1,3 @@
-use super::super::app::App;
-use super::utils::{
-  layout_block_active, loading, style_highlight, style_primary, style_success, style_warning,
-  table_header_style,
-};
-
 use kubectl_view_allocations::{qty::Qty, tree::provide_prefix};
 use tui::{
   backend::Backend,
@@ -12,6 +6,12 @@ use tui::{
   Frame,
 };
 
+use super::utils::{
+  layout_block_active, loading, style_highlight, style_primary, style_success, style_warning,
+  table_header_style,
+};
+use crate::app::App;
+
 pub fn draw_utilization<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
   let title = format!(
     "Resource Utilization (ns: [{}], group by <g>: {:?})",
